==> telescope.1.4.zip: 3rdparty/wtf/wtf/PlatformTelescope.h <==
#ifndef CMAKECONFIG_H
#define CMAKECONFIG_H

#if defined( WTF_PLATFORM_TELESCOPE )
#undef WTF_PLATFORM_TELESCOPE
#endif

#define WTF_PLATFORM_TELESCOPE 1


#define ENABLE_3D_TRANSFORMS 1
#define ENABLE_ACCELERATED_2D_CANVAS 0
#define ENABLE_ACCESSIBILITY_STATIC_TREE 0
#define ENABLE_API_TESTS 1
#define ENABLE_APPLE_PAY 0
#define ENABLE_APPLE_PAY_SESSION_V3 0
#define ENABLE_APPLE_PAY_SESSION_V4 0
#define ENABLE_APPLICATION_MANIFEST 1
#define ENABLE_ASYNC_SCROLLING 0
#define ENABLE_ATTACHMENT_ELEMENT 1
#define ENABLE_AUTOCAPITALIZE 0
#define ENABLE_AVF_CAPTIONS 0
#define ENABLE_BUBBLEWRAP_SANDBOX 0
#define ENABLE_CACHE_PARTITIONING 0
#define ENABLE_CHANNEL_MESSAGING 1
#define ENABLE_CONTENT_EXTENSIONS 0
#define ENABLE_CONTENT_FILTERING 0
#define ENABLE_CONTEXT_MENUS 0
#define ENABLE_CSS3_TEXT 0
#define ENABLE_CSS_BOX_DECORATION_BREAK 1
#define ENABLE_CSS_COMPOSITING 1
#define ENABLE_CSS_CONIC_GRADIENTS 0
#define ENABLE_CSS_DEVICE_ADAPTATION 0
#define ENABLE_CSS_IMAGE_ORIENTATION 0
#define ENABLE_CSS_IMAGE_RESOLUTION 0
#define ENABLE_CSS_PAINTING_API 1
#define ENABLE_CSS_SCROLL_SNAP 0
#define ENABLE_CSS_SELECTORS_LEVEL4 1
#define ENABLE_CSS_TRAILING_WORD 0
#define ENABLE_CSS_TYPED_OM 1
#define ENABLE_CURSOR_VISIBILITY 1
#define ENABLE_CUSTOM_SCHEME_HANDLER 0
#define ENABLE_DARK_MODE_CSS 0
#define ENABLE_DATACUE_VALUE 0
#define ENABLE_DATALIST_ELEMENT 0
#define ENABLE_DATA_INTERACTION 0
#define ENABLE_DEVELOPER_MODE 1
#define ENABLE_DEVICE_ORIENTATION 0
#define ENABLE_DFG_JIT 1
#define ENABLE_DOWNLOAD_ATTRIBUTE 0
#define ENABLE_ENCRYPTED_MEDIA 0
#define ENABLE_EXPERIMENTAL_FEATURES 1
#define ENABLE_FAST_JIT_PERMISSIONS 0
#define ENABLE_FETCH_API 1
#define ENABLE_FILTERS_LEVEL_2 1
#define ENABLE_FTL_JIT 0
#define ENABLE_FTPDIR 1
#define ENABLE_FULLSCREEN_API 1
#define ENABLE_GAMEPAD 0
#define ENABLE_GEOLOCATION 0
#define ENABLE_GRAPHICS_CONTEXT_GL 0
#define ENABLE_INDEXED_DATABASE_IN_WORKERS 1
#define ENABLE_INPUT_TYPE_COLOR 0
#define ENABLE_INPUT_TYPE_DATE 0
#define ENABLE_INPUT_TYPE_DATETIMELOCAL 0
#define ENABLE_INPUT_TYPE_DATETIME_INCOMPLETE 0
#define ENABLE_INPUT_TYPE_MONTH 0
#define ENABLE_INPUT_TYPE_TIME 0
#define ENABLE_INPUT_TYPE_WEEK 0
#define ENABLE_INSPECTOR_ALTERNATE_DISPATCHERS 0
#define ENABLE_INSPECTOR_TELEMETRY 0
#define ENABLE_INTERSECTION_OBSERVER 1
#define ENABLE_INTL 0
#define ENABLE_IOS_GESTURE_EVENTS 0
#define ENABLE_IOS_TOUCH_EVENTS 0
#define ENABLE_LAYOUT_FORMATTING_CONTEXT 1
#define ENABLE_LEGACY_CSS_VENDOR_PREFIXES 1
#define ENABLE_LEGACY_CUSTOM_PROTOCOL_MANAGER 0
#define ENABLE_LEGACY_ENCRYPTED_MEDIA 0
#define ENABLE_LETTERPRESS 0
#define ENABLE_MAC_GESTURE_EVENTS 0
#define ENABLE_MAC_VIDEO_TOOLBOX 0
#define ENABLE_MATHML 1
#define ENABLE_MEDIA_CAPTURE 0
#define ENABLE_MEDIA_CONTROLS_SCRIPT 0
#define ENABLE_MEDIA_SESSION 0
#define ENABLE_MEDIA_SOURCE 0
#define ENABLE_MEDIA_STATISTICS 0
#define ENABLE_MEDIA_STREAM 0
#define ENABLE_MEMORY_SAMPLER 0
#define ENABLE_METER_ELEMENT 1
#define ENABLE_MHTML 0
#define ENABLE_MINIBROWSER 0
#define ENABLE_MOUSE_CURSOR_SCALE 1
#define ENABLE_NETSCAPE_PLUGIN_API 0
#define ENABLE_NETWORK_CACHE_SPECULATIVE_REVALIDATION 0
#define ENABLE_NETWORK_CACHE_STALE_WHILE_REVALIDATE 0
#define ENABLE_NOTIFICATIONS 0
#define ENABLE_OFFSCREEN_CANVAS 0
#define ENABLE_ORIENTATION_EVENTS 0
#define ENABLE_OVERFLOW_SCROLLING_TOUCH 0
#define ENABLE_PAYMENT_REQUEST 0
#define ENABLE_PDFKIT_PLUGIN 0
#define ENABLE_PICTURE_IN_PICTURE_API 0
#define ENABLE_POINTER_EVENTS 0
#define ENABLE_POINTER_LOCK 0
#define ENABLE_PUBLIC_SUFFIX_LIST 0
#define ENABLE_QUOTA 0
#define ENABLE_RESIZE_OBSERVER 1
#define ENABLE_RESOLUTION_MEDIA_QUERY 0
#define ENABLE_RESOURCE_LOAD_STATISTICS 1
#define ENABLE_RESOURCE_USAGE 1
#define ENABLE_RUBBER_BANDING 0
#define ENABLE_SANDBOX_EXTENSIONS 0
#define ENABLE_SERVER_PRECONNECT 0
#define ENABLE_SERVICE_CONTROLS 0
#define ENABLE_SERVICE_WORKER 1
#define ENABLE_SHAREABLE_RESOURCE 0
#define ENABLE_SMOOTH_SCROLLING 0
#define ENABLE_SPEECH_SYNTHESIS 0
#define ENABLE_SPELLCHECK 0
#define ENABLE_STREAMS_API 1
#define ENABLE_SVG_FONTS 1
#define ENABLE_TELEPHONE_NUMBER_DETECTION 0
#define ENABLE_TEXT_AUTOSIZING 0
#define ENABLE_TOUCH_EVENTS 0
#define ENABLE_TOUCH_SLIDER 0
#define ENABLE_UNIFIED_BUILDS 1
#define ENABLE_USERSELECT_ALL 0
#define ENABLE_USER_MESSAGE_HANDLERS 1
#define ENABLE_VARIATION_FONTS 1
#define ENABLE_VIDEO 0
#define ENABLE_VIDEO_PRESENTATION_MODE 0
#define ENABLE_VIDEO_TRACK 0
#define ENABLE_VIDEO_USES_ELEMENT_FULLSCREEN 0
#define ENABLE_WEBASSEMBLY 0
#define ENABLE_WEBASSEMBLY_STREAMING_API 0
#define ENABLE_WEBDRIVER 1
#define ENABLE_WEBDRIVER_KEYBOARD_INTERACTIONS 0
#define ENABLE_WEBDRIVER_MOUSE_INTERACTIONS 0
#define ENABLE_WEBGL 0
#define ENABLE_WEBGL2 0
#define ENABLE_WEBGPU 0
#define ENABLE_WEB_AUDIO 0
#define ENABLE_WEB_AUTHN 0
#define ENABLE_WEB_CRYPTO 0
#define ENABLE_WEB_PROCESS_SANDBOX 0
#define ENABLE_WEB_RTC 0
#define ENABLE_WIRELESS_PLAYBACK_TARGET 0
#define ENABLE_XSLT 0
#define HAVE_ALIGNED_MALLOC 1
#define HAVE_ERRNO_H 1
#define HAVE_FEATURES_H 0
#define HAVE_LANGINFO_H 0
#define HAVE_LINUX_MEMFD_H 0
#define HAVE_LOCALTIME_R 0
#define HAVE_MALLOC_TRIM 0
#define HAVE_MMAP 0
#define HAVE_OPENGL_ES_3 1
#define HAVE_PTHREAD_MAIN_NP 0
#define HAVE_PTHREAD_NP_H 0
#define HAVE_REGEX_H 0
#define HAVE_SIGNAL_H 0
#define HAVE_STAT_BIRTHTIME 0
#define HAVE_STRNSTR 0
#define HAVE_SYS_TIME_H 0
#define HAVE_TIMEGM 0
#define HAVE_TM_GMTOFF 0
#define HAVE_TM_ZONE 0
#define HAVE_VASPRINTF 0
#define USE_CAIRO 1
#define USE_CF 0
#define USE_CURL 1
#define USE_EGL 0
#define USE_INSPECTOR_SOCKET_SERVER 1
#define USE_MEDIA_FOUNDATION 0
#define USE_OPENGL_ES 0
#define USE_OPENJPEG 0
#define USE_OPENSSL 1
#define USE_SYSTEM_MALLOC 1
#define USE_TEXTURE_MAPPER 1
#define USE_TEXTURE_MAPPER_GL 0
#define USE_VERSION_STAMPER 0
#define USE_WEBP 0
#define WTF_CPU_ARM64_CORTEXA53 0
#define ENABLE_INDEXED_DATABASE 1
#define ENABLE_OUTSIDE_CURL 1

#ifdef SONY_PLATFORM
#define ENABLE_REMOTE_INSPECTOR 0
#define ENABLE_SAMPLING_PROFILER 0
#define HAVE_ISDEBUGGERPRESENT 0
#define HAVE_SYS_TIMEB_H 0
#define ENABLE_ACCESSIBILITY 0
#define ENABLE_DRAG_SUPPORT 0
#else
#define ENABLE_REMOTE_INSPECTOR 1
#define ENABLE_SAMPLING_PROFILER 1
#define HAVE_ISDEBUGGERPRESENT 1
#define HAVE_SYS_TIMEB_H 1
#define ENABLE_ACCESSIBILITY 0
#define ENABLE_DRAG_SUPPORT 1
#endif // SONY_PLATFORM

#ifdef SONY_PLATFORM
#include <net.h>
extern uint16_t telNetHtons( uint16_t host16 );
extern uint32_t telNetHtonl( uint32_t host32 );
extern uint32_t telNetNtohl( uint32_t net32 );
#define WTF_SONY_PLATFORM_CPU_CORES	4
#define WTF_OS_SONY_PLATFORM 1
#define WTF_SONY_PLATFORM_MEMORY_SIZE	1 * 1024 * 1024 * 1024
#define htons telNetHtons
#define htonl telNetHtonl
#define ntohl telNetNtohl
typedef void * HANDLE;
#define _exit _Exit
#define gmtime_r gmtime_s
#define DWORD unsigned int;
#define DEFAULT_CHARSET 0
#endif

#define USE_TEXTURE_MAPPER_TELESCOPE 1

#if defined(TS_PLATFORM_WINDOWS) || defined(_WINDOWS)
//#undef ENABLE_JIT
//#undef ENABLE_DFG_JIT
//#undef ENABLE_C_LOOP
//#define ENABLE_JIT	0
//#define ENABLE_DFG_JIT 0
//#define ENABLE_C_LOOP 1
#define TS_PLATFORM_NAME	"WINDOWS"
#define TS_PLATFORM_MICROSOFT 1
#undef ENABLE_INDEXED_DATABASE
#define ENABLE_INDEXED_DATABASE 0
#undef ENABLE_INDEXED_DATABASE_IN_WORKERS
#define ENABLE_INDEXED_DATABASE_IN_WORKERS 0
#undef ENABLE_CONTEXT_MENUS
#define ENABLE_CONTEXT_MENUS 0
#undef ENABLE_DRAG_SUPPORT
#define ENABLE_DRAG_SUPPORT 0
#define ENABLE_C_LOOP 0
#define ENABLE_JIT 1
#define USE_FREETYPE 1
#define USE_HARFBUZZ 1
#define ENABLE_VIRTUAL_ALLOCATION 0
#elif defined(TS_PLATFORM_XBOX) || defined(IS_XB3) || defined(IS_XB4)
#undef ENABLE_JIT
#undef ENABLE_DFG_JIT
#undef ENABLE_C_LOOP
#undef ENABLE_SAMPLING_PROFILER
#define ENABLE_C_LOOP 1
#define ENABLE_JIT 0
#define ENABLE_DFG_JIT 0
#define ENABLE_FTL_JIT 0
#define ENABLE_SAMPLING_PROFILER 0
#define TS_PLATFORM_NAME	"XBOX"
#define TS_PLATFORM_MICROSOFT 1
#define ENABLE_VIRTUAL_ALLOCATION 0
#if defined(ENABLE_ACCESSIBILITY)
#undef ENABLE_ACCESSIBILITY
#endif
#define ENABLE_ACCESSIBILITY 0
#if defined(ENABLE_DRAG_SUPPORT)
#undef ENABLE_DRAG_SUPPORT
#endif
#define ENABLE_DRAG_SUPPORT 0
#undef ENABLE_INDEXED_DATABASE
#define ENABLE_INDEXED_DATABASE 0
#undef ENABLE_INDEXED_DATABASE_IN_WORKERS
#define ENABLE_INDEXED_DATABASE_IN_WORKERS 0
#undef ENABLE_CONTEXT_MENUS
#define ENABLE_CONTEXT_MENUS 0
#define USE_FREETYPE 1
#define USE_HARFBUZZ 1
#elif defined(SONY_PLATFORM)
#define TS_PLATFORM_NAME	"PLAYSTATION"
#define TS_PLATFORM_MICROSOFT 0
#undef ENABLE_INDEXED_DATABASE
#define ENABLE_INDEXED_DATABASE 0
#undef ENABLE_INDEXED_DATABASE_IN_WORKERS
#define ENABLE_INDEXED_DATABASE_IN_WORKERS 0
#undef ENABLE_CONTEXT_MENUS
#define ENABLE_CONTEXT_MENUS 0
#undef ENABLE_DRAG_SUPPORT
#define ENABLE_DRAG_SUPPORT 0
#define ENABLE_C_LOOP 1
#define ENABLE_JIT 0
#define USE_FREETYPE 1
#define USE_HARFBUZZ 1
#define ENABLE_VIRTUAL_ALLOCATION 0
#endif

#endif /* CMAKECONFIG_H */

==> telescope.1.15.zip: 3rdparty/wtf/wtf/PlatformTelescope.h <==
#ifndef CMAKECONFIG_H
#define CMAKECONFIG_H

#if defined( WTF_PLATFORM_TELESCOPE )
#undef WTF_PLATFORM_TELESCOPE
#endif

#define WTF_PLATFORM_TELESCOPE 1


#define ENABLE_3D_TRANSFORMS 1
#define ENABLE_ACCELERATED_2D_CANVAS 0
#define ENABLE_ACCESSIBILITY_STATIC_TREE 0
#define ENABLE_API_TESTS 1
#define ENABLE_APPLE_PAY 0
#define ENABLE_APPLE_PAY_SESSION_V3 0
#define ENABLE_APPLE_PAY_SESSION_V4 0
#define ENABLE_APPLICATION_MANIFEST 1
#define ENABLE_ASYNC_SCROLLING 0
#define ENABLE_ATTACHMENT_ELEMENT 1
#define ENABLE_AUTOCAPITALIZE 0
#define ENABLE_AVF_CAPTIONS 0
#define ENABLE_BUBBLEWRAP_SANDBOX 0
#define ENABLE_CACHE_PARTITIONING 0
#define ENABLE_CHANNEL_MESSAGING 1
#define ENABLE_CONTENT_EXTENSIONS 0
#define ENABLE_CONTENT_FILTERING 0
#define ENABLE_CONTEXT_MENUS 0
#define ENABLE_CSS3_TEXT 0
#define ENABLE_CSS_BOX_DECORATION_BREAK 1
#define ENABLE_CSS_COMPOSITING 1
#define ENABLE_CSS_CONIC_GRADIENTS 0
#define ENABLE_CSS_DEVICE_ADAPTATION 0
#define ENABLE_CSS_IMAGE_ORIENTATION 0
#define ENABLE_CSS_IMAGE_RESOLUTION 0
#define ENABLE_CSS_PAINTING_API 1
#define ENABLE_CSS_SCROLL_SNAP 0
#define ENABLE_CSS_SELECTORS_LEVEL4 1
#define ENABLE_CSS_TRAILING_WORD 0
#define ENABLE_CSS_TYPED_OM 1
#define ENABLE_CURSOR_VISIBILITY 1
#define ENABLE_CUSTOM_SCHEME_HANDLER 0
#define ENABLE_DARK_MODE_CSS 0
#define ENABLE_DATACUE_VALUE 0
#define ENABLE_DATALIST_ELEMENT 0
#define ENABLE_DATA_INTERACTION 0
#define ENABLE_DEVELOPER_MODE 1
#define ENABLE_DEVICE_ORIENTATION 0
#define ENABLE_DFG_JIT 1
#define ENABLE_DOWNLOAD_ATTRIBUTE 0
#define ENABLE_ENCRYPTED_MEDIA 0
#define ENABLE_EXPERIMENTAL_FEATURES 1
#define ENABLE_FAST_JIT_PERMISSIONS 0
#define ENABLE_FETCH_API 1
#define ENABLE_FILTERS_LEVEL_2 1
#define ENABLE_FTL_JIT 0
#define ENABLE_FTPDIR 1
#define ENABLE_FULLSCREEN_API 1
#define ENABLE_GAMEPAD 0
#define ENABLE_GEOLOCATION 0
#define ENABLE_GRAPHICS_CONTEXT_GL 0
#define ENABLE_INDEXED_DATABASE_IN_WORKERS 1
#define ENABLE_INPUT_TYPE_COLOR 0
#define ENABLE_INPUT_TYPE_DATE 0
#define ENABLE_INPUT_TYPE_DATETIMELOCAL 0
#define ENABLE_INPUT_TYPE_DATETIME_INCOMPLETE 0
#define ENABLE_INPUT_TYPE_MONTH 0
#define ENABLE_INPUT_TYPE_TIME 0
#define ENABLE_INPUT_TYPE_WEEK 0
#define ENABLE_INSPECTOR_ALTERNATE_DISPATCHERS 0
#define ENABLE_INSPECTOR_TELEMETRY 0
#define ENABLE_INTERSECTION_OBSERVER 1
#define ENABLE_INTL 0
#define ENABLE_IOS_GESTURE_EVENTS 0
#define ENABLE_IOS_TOUCH_EVENTS 0
#define ENABLE_LAYOUT_FORMATTING_CONTEXT 1
#define ENABLE_LEGACY_CSS_VENDOR_PREFIXES 1
#define ENABLE_LEGACY_CUSTOM_PROTOCOL_MANAGER 0
#define ENABLE_LEGACY_ENCRYPTED_MEDIA 0
#define ENABLE_LETTERPRESS 0
#define ENABLE_MAC_GESTURE_EVENTS 0
#define ENABLE_MAC_VIDEO_TOOLBOX 0
#define ENABLE_MATHML 1
#define ENABLE_MEDIA_CAPTURE 0
#define ENABLE_MEDIA_CONTROLS_SCRIPT 1	/* TELESCOPE_LIB_CHANGES 2020-12-28 Enable video related macros */
#define ENABLE_MEDIA_SESSION 0
#define ENABLE_MEDIA_SOURCE 0
#define ENABLE_MEDIA_STATISTICS 0
#define ENABLE_MEDIA_STREAM 0
#define ENABLE_MEMORY_SAMPLER 0
#define ENABLE_METER_ELEMENT 1
#define ENABLE_MHTML 0
#define ENABLE_MINIBROWSER 0
#define ENABLE_MOUSE_CURSOR_SCALE 1
#define ENABLE_NETSCAPE_PLUGIN_API 0
#define ENABLE_NETWORK_CACHE_SPECULATIVE_REVALIDATION 0
#define ENABLE_NETWORK_CACHE_STALE_WHILE_REVALIDATE 0
#define ENABLE_NOTIFICATIONS 0
#define ENABLE_OFFSCREEN_CANVAS 0
#define ENABLE_ORIENTATION_EVENTS 0
#define ENABLE_OVERFLOW_SCROLLING_TOUCH 0
#define ENABLE_PAYMENT_REQUEST 0
#define ENABLE_PDFKIT_PLUGIN 0
#define ENABLE_PICTURE_IN_PICTURE_API 0
#define ENABLE_POINTER_EVENTS 0
#define ENABLE_POINTER_LOCK 0
#define ENABLE_PUBLIC_SUFFIX_LIST 0
#define ENABLE_QUOTA 0
#define ENABLE_RESIZE_OBSERVER 1
#define ENABLE_RESOLUTION_MEDIA_QUERY 0
#define ENABLE_RESOURCE_LOAD_STATISTICS 1
#define ENABLE_RESOURCE_USAGE 1
#define ENABLE_RUBBER_BANDING 0
#define ENABLE_SANDBOX_EXTENSIONS 0
#define ENABLE_SERVER_PRECONNECT 0
#define ENABLE_SERVICE_CONTROLS 0
#define ENABLE_SERVICE_WORKER 1
#define ENABLE_SHAREABLE_RESOURCE 0
#define ENABLE_SMOOTH_SCROLLING 0
#define ENABLE_SPEECH_SYNTHESIS 0
#define ENABLE_SPELLCHECK 0
#define ENABLE_STREAMS_API 1
#define ENABLE_SVG_FONTS 1
#define ENABLE_TELEPHONE_NUMBER_DETECTION 0
#define ENABLE_TEXT_AUTOSIZING 0
#define ENABLE_TOUCH_EVENTS 0
#define ENABLE_TOUCH_SLIDER 0
#define ENABLE_UNIFIED_BUILDS 1
#define ENABLE_USERSELECT_ALL 0
#define ENABLE_USER_MESSAGE_HANDLERS 1
#define ENABLE_VARIATION_FONTS 1
//+TELESCOPE_LIB_CHANGES 
// 2020-12-28 
// Enable video related macros
#define ENABLE_VIDEO 1	
#define ENABLE_VIDEO_TRACK 1
#define ENABLE_VIDEO_USES_ELEMENT_FULLSCREEN 1	
//-TELESCOPE_LIB_CHANGES
#define ENABLE_VIDEO_PRESENTATION_MODE 0
#define ENABLE_WEBASSEMBLY 0
#define ENABLE_WEBASSEMBLY_STREAMING_API 0
#define ENABLE_WEBDRIVER 1
#define ENABLE_WEBDRIVER_KEYBOARD_INTERACTIONS 0
#define ENABLE_WEBDRIVER_MOUSE_INTERACTIONS 0
#define ENABLE_WEBGL 0
#define ENABLE_WEBGL2 0
#define ENABLE_WEBGPU 0
#define ENABLE_WEB_AUDIO 0
#define ENABLE_WEB_AUTHN 0
#define ENABLE_WEB_CRYPTO 0
#define ENABLE_WEB_PROCESS_SANDBOX 0
#define ENABLE_WEB_RTC 0
#define ENABLE_WIRELESS_PLAYBACK_TARGET 0
#define ENABLE_XSLT 0
#define HAVE_ALIGNED_MALLOC 1
#define HAVE_ERRNO_H 1
#define HAVE_FEATURES_H 0
#define HAVE_LANGINFO_H 0
#define HAVE_LINUX_MEMFD_H 0
#define HAVE_LOCALTIME_R 0
#define HAVE_MALLOC_TRIM 0
#define HAVE_MMAP 0
#define HAVE_OPENGL_ES_3 1
#define HAVE_PTHREAD_MAIN_NP 0
#define HAVE_PTHREAD_NP_H 0
#define HAVE_REGEX_H 0
#define HAVE_SIGNAL_H 0
#define HAVE_STAT_BIRTHTIME 0
#define HAVE_STRNSTR 0
#define HAVE_SYS_TIME_H 0
#define HAVE_TIMEGM 0
#define HAVE_TM_GMTOFF 0
#define HAVE_TM_ZONE 0
#define HAVE_VASPRINTF 0
#define USE_CAIRO 1
#define USE_CF 0
#define USE_CURL 1
#define USE_EGL 0
#define USE_INSPECTOR_SOCKET_SERVER 1
#define USE_MEDIA_FOUNDATION 0
#define USE_OPENGL_ES 0
#define USE_OPENJPEG 0
#define USE_OPENSSL 1
#define USE_SYSTEM_MALLOC 1
#define USE_TEXTURE_MAPPER 1
#define USE_TEXTURE_MAPPER_GL 0
#define USE_VERSION_STAMPER 0
#define USE_WEBP 0
#define WTF_CPU_ARM64_CORTEXA53 0
#define ENABLE_INDEXED_DATABASE 1
#define ENABLE_OUTSIDE_CURL 1

#define ENABLE_DEVGUI 1
#ifdef SONY_PLATFORM
#define ENABLE_REMOTE_INSPECTOR 0
#define ENABLE_SAMPLING_PROFILER 0
#define HAVE_ISDEBUGGERPRESENT 0
#define HAVE_SYS_TIMEB_H 0
#define ENABLE_ACCESSIBILITY 0
#define ENABLE_DRAG_SUPPORT 0
#else
#define ENABLE_REMOTE_INSPECTOR 1
#define ENABLE_SAMPLING_PROFILER 1
#define HAVE_ISDEBUGGERPRESENT 1
#define HAVE_SYS_TIMEB_H 1
#define ENABLE_ACCESSIBILITY 0
#define ENABLE_DRAG_SUPPORT 1
#endif // SONY_PLATFORM

#ifdef SONY_PLATFORM
#include <net.h>
extern uint16_t telNetHtons( uint16_t host16 );
extern uint32_t telNetHtonl( uint32_t host32 );
extern uint32_t telNetNtohl( uint32_t net32 );
#define WTF_SONY_PLATFORM_CPU_CORES	4
#define WTF_OS_SONY_PLATFORM 1
#define WTF_SONY_PLATFORM_MEMORY_SIZE	1 * 1024 * 1024 * 1024
#define htons telNetHtons
#define htonl telNetHtonl
#define ntohl telNetNtohl
typedef void * HANDLE;
#define _exit _Exit
#define gmtime_r gmtime_s
#define DWORD unsigned int;
#define DEFAULT_CHARSET 0
#endif

#define USE_TEXTURE_MAPPER_TELESCOPE 1

#if defined(TS_PLATFORM_WINDOWS) || defined(_WINDOWS)
//#undef ENABLE_JIT
//#undef ENABLE_DFG_JIT
//#undef ENABLE_C_LOOP
//#define ENABLE_JIT	0
//#define ENABLE_DFG_JIT 0
//#define ENABLE_C_LOOP 1
#define TS_PLATFORM_NAME	"WINDOWS"
#define TS_PLATFORM_MICROSOFT 1
#undef ENABLE_INDEXED_DATABASE
#define ENABLE_INDEXED_DATABASE 0
#undef ENABLE_INDEXED_DATABASE_IN_WORKERS
#define ENABLE_INDEXED_DATABASE_IN_WORKERS 0
#undef ENABLE_CONTEXT_MENUS
#define ENABLE_CONTEXT_MENUS 0
#undef ENABLE_DRAG_SUPPORT
#define ENABLE_DRAG_SUPPORT 0
#define ENABLE_C_LOOP 0
#define ENABLE_JIT 1
#define USE_FREETYPE 1
#define USE_HARFBUZZ 1
#define ENABLE_VIRTUAL_ALLOCATION 0
#elif defined(TS_PLATFORM_XBOX) || defined(IS_XB3) || defined(IS_XB4)
#undef ENABLE_JIT
#undef ENABLE_DFG_JIT
#undef ENABLE_C_LOOP
#undef ENABLE_SAMPLING_PROFILER
#define ENABLE_C_LOOP 1
#define ENABLE_JIT 0
#define ENABLE_DFG_JIT 0
#define ENABLE_FTL_JIT 0
#define ENABLE_SAMPLING_PROFILER 0
#define TS_PLATFORM_NAME	"XBOX"
#define TS_PLATFORM_MICROSOFT 1
#define ENABLE_VIRTUAL_ALLOCATION 0
#if defined(ENABLE_ACCESSIBILITY)
#undef ENABLE_ACCESSIBILITY
#endif
#define ENABLE_ACCESSIBILITY 0
#if defined(ENABLE_DRAG_SUPPORT)
#undef ENABLE_DRAG_SUPPORT
#endif
#define ENABLE_DRAG_SUPPORT 0
#undef ENABLE_INDEXED_DATABASE
#define ENABLE_INDEXED_DATABASE 0
#undef ENABLE_INDEXED_DATABASE_IN_WORKERS
#define ENABLE_INDEXED_DATABASE_IN_WORKERS 0
#undef ENABLE_CONTEXT_MENUS
#define ENABLE_CONTEXT_MENUS 0
#define USE_FREETYPE 1
#define USE_HARFBUZZ 1
#elif defined(SONY_PLATFORM)
#define TS_PLATFORM_NAME	"PLAYSTATION"
#define TS_PLATFORM_MICROSOFT 0
#undef ENABLE_INDEXED_DATABASE
#define ENABLE_INDEXED_DATABASE 0
#undef ENABLE_INDEXED_DATABASE_IN_WORKERS
#define ENABLE_INDEXED_DATABASE_IN_WORKERS 0
#undef ENABLE_CONTEXT_MENUS
#define ENABLE_CONTEXT_MENUS 0
#undef ENABLE_DRAG_SUPPORT
#define ENABLE_DRAG_SUPPORT 0
#define ENABLE_C_LOOP 1
#define ENABLE_JIT 0
#define USE_FREETYPE 1
#define USE_HARFBUZZ 1
#define ENABLE_VIRTUAL_ALLOCATION 0
#endif

//+TELESCOPE_LIB_CHANGES 
// 2021-03-24 
// define a dummy getenv function for SONY_PLATFORM and Durango XDK
#if defined(SONY_PLATFORM) || defined(_XBOX_ONE)
static inline char *getenv(const char *name)
{
    static char emptyStr[1] = "";
    return emptyStr;
}
#endif
//-TELESCOPE_LIB_CHANGES 

#endif /* CMAKECONFIG_H */
